@@ -1,6 +1,7 @@
 import click
 
 from slackdump.scraper import run_scraper
+from slackdump.chrome import osx_chrome
 
 
 @click.command()
@@ -11,4 +12,9 @@ from slackdump.scraper import run_scraper
     help="The url to your channel, eg: https://somewhere.slack.com/messages/66666666",
 )
 def cli(rooturl):
-    run_scraper(rooturl)
+    with osx_chrome() as debug_url:
+        run_scraper(rooturl, debug_url)
+
+
+if __name__ == "__main__":
+    cli()
\ No newline at end of file
